==> openshift-model-operatorhub-5.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StrategyDeploymentSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.model.apps.DeploymentSpec;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class StrategyDeploymentSpecFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.StrategyDeploymentSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.StrategyDeploymentSpecFluent<A>{
  public StrategyDeploymentSpecFluentImpl() {
  }
  public StrategyDeploymentSpecFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.StrategyDeploymentSpec instance) {
    this.withLabel(instance.getLabel()); 
    this.withName(instance.getName()); 
    this.withSpec(instance.getSpec()); 
  }
  private java.util.Map<java.lang.String,java.lang.String> label;
  private java.lang.String name;
  private io.fabric8.kubernetes.api.model.apps.DeploymentSpec spec;
  public A addToLabel(java.lang.String key,java.lang.String value) {
    if(this.label == null && key != null && value != null) { this.label = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.label.put(key, value);} return (A)this;
  }
  public A addToLabel(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.label == null && map != null) { this.label = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.label.putAll(map);} return (A)this;
  }
  public A removeFromLabel(java.lang.String key) {
    if(this.label == null) { return (A) this; }
    if(key != null && this.label != null) {this.label.remove(key);} return (A)this;
  }
  public A removeFromLabel(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.label == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.label != null){this.label.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getLabel() {
    return this.label;
  }
  public <K,V>A withLabel(java.util.Map<java.lang.String,java.lang.String> label) {
    if (label == null) { this.label =  null;} else {this.label = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(label);} return (A) this;
  }
  public java.lang.Boolean hasLabel() {
    return this.label != null;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.apps.DeploymentSpec getSpec() {
    return this.spec;
  }
  public A withSpec(io.fabric8.kubernetes.api.model.apps.DeploymentSpec spec) {
    this.spec=spec; return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StrategyDeploymentSpecFluentImpl that = (StrategyDeploymentSpecFluentImpl) o;
    if (label != null ? !label.equals(that.label) :that.label != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(label,  name,  spec,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.11.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/StrategyDeploymentSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.model.apps.DeploymentSpec;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class StrategyDeploymentSpecFluentImpl<A extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.StrategyDeploymentSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operatorhub.v1alpha1.StrategyDeploymentSpecFluent<A>{
  public StrategyDeploymentSpecFluentImpl() {
  }
  public StrategyDeploymentSpecFluentImpl(io.fabric8.openshift.api.model.operatorhub.v1alpha1.StrategyDeploymentSpec instance) {
    this.withLabel(instance.getLabel()); 
    this.withName(instance.getName()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.Map<java.lang.String,java.lang.String> label;
  private java.lang.String name;
  private io.fabric8.kubernetes.api.model.apps.DeploymentSpec spec;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToLabel(java.lang.String key,java.lang.String value) {
    if(this.label == null && key != null && value != null) { this.label = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(key != null && value != null) {this.label.put(key, value);} return (A)this;
  }
  public A addToLabel(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.label == null && map != null) { this.label = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(); }
    if(map != null) { this.label.putAll(map);} return (A)this;
  }
  public A removeFromLabel(java.lang.String key) {
    if(this.label == null) { return (A) this; }
    if(key != null && this.label != null) {this.label.remove(key);} return (A)this;
  }
  public A removeFromLabel(java.util.Map<java.lang.String,java.lang.String> map) {
    if(this.label == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.label != null){this.label.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.String> getLabel() {
    return this.label;
  }
  public <K,V>A withLabel(java.util.Map<java.lang.String,java.lang.String> label) {
    if (label == null) { this.label =  null;} else {this.label = new java.util.LinkedHashMap<java.lang.String,java.lang.String>(label);} return (A) this;
  }
  public java.lang.Boolean hasLabel() {
    return this.label != null;
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public io.fabric8.kubernetes.api.model.apps.DeploymentSpec getSpec() {
    return this.spec;
  }
  public A withSpec(io.fabric8.kubernetes.api.model.apps.DeploymentSpec spec) {
    this.spec=spec; return (A) this;
  }
  public java.lang.Boolean hasSpec() {
    return this.spec != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    StrategyDeploymentSpecFluentImpl that = (StrategyDeploymentSpecFluentImpl) o;
    if (label != null ? !label.equals(that.label) :that.label != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(label,  name,  spec,  additionalProperties,  super.hashCode());
  }
  
}
